mutation StartChatTurn($chatInput: ChatInput!, $chatConfig: ChatConfigInput!) {
    startChatTurn(
        input: {
            chatInput: $chatInput,
            chatConfigInput: $chatConfig
        }
    ) {
        __typename
        ... on Chat {
            chatUuid
        }
    }
}
