# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal
from uuid import UUID

from pydantic import Field

from .base_model import BaseModel


class CreateCloudChatFromRepository(BaseModel):
    create_chat_with_resource_config: (
        "CreateCloudChatFromRepositoryCreateChatWithResourceConfig"
    ) = Field(alias="createChatWithResourceConfig")


class CreateCloudChatFromRepositoryCreateChatWithResourceConfig(BaseModel):
    typename__: Literal["Chat"] = Field(alias="__typename")
    chat_uuid: UUID = Field(alias="chatUuid")


CreateCloudChatFromRepository.model_rebuild()
