# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal
from uuid import UUID

from pydantic import Field

from .base_model import BaseModel


class StartChatTurn(BaseModel):
    start_chat_turn: "StartChatTurnStartChatTurn" = Field(alias="startChatTurn")


class StartChatTurnStartChatTurn(BaseModel):
    typename__: Literal["Chat"] = Field(alias="__typename")
    chat_uuid: UUID = Field(alias="chatUuid")


StartChatTurn.model_rebuild()
