# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal

from pydantic import Field

from .base_model import BaseModel


class SetLoginComplete(BaseModel):
    set_login_complete: "SetLoginCompleteSetLoginComplete" = Field(
        alias="setLoginComplete"
    )


class SetLoginCompleteSetLoginComplete(BaseModel):
    typename__: Literal["User"] = Field(alias="__typename")
    user_api_key: str = Field(alias="userApiKey")


SetLoginComplete.model_rebuild()
