# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from uuid import UUID

from pydantic import Field

from .base_model import BaseModel


class CurrentUser(BaseModel):
    current_user: "CurrentUserCurrentUser" = Field(alias="currentUser")


class CurrentUserCurrentUser(BaseModel):
    user_uuid: UUID = Field(alias="userUuid")


CurrentUser.model_rebuild()
