query Chats($userUuids: [UUID!] = null) {
    organizationChatsPage(userUuids: $userUuids, limit: 200) {
        ... on OrganizationChatsPage {
            chats {
                chatUuid
                name
                subtitle
                isShared
                isStarted
                updatedAt
                prStatus {
                    ... on PRInfo {
                        number
                        title
                        status
                    }
                }
            }
        }
    }
}
