# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal

from pydantic import Field

from .base_model import BaseModel


class RefreshApiKey(BaseModel):
    refresh_api_key: "RefreshApiKeyRefreshApiKey" = Field(alias="refreshApiKey")


class RefreshApiKeyRefreshApiKey(BaseModel):
    typename__: Literal["User"] = Field(alias="__typename")
    user_api_key: str = Field(alias="userApiKey")


RefreshApiKey.model_rebuild()
